* Activity 2 answers.

* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE activity /NAME = "C:\Dropbox\14_ICPSR\Download\Activities".
GET FILE = "activity/SPSS_Activity_Data.sav".
DATASET NAME activity WINDOW=FRONT.

* Getting person mean stress (for later).
COMPUTE pmstress = MEAN(stress1 TO stress5).
VARIABLE LABELS PMstress "Person Mean Stress".
EXECUTE.

* Stacking data for MIXED.
VARSTOCASES
	/MAKE severity FROM severity1 TO severity5
	/MAKE stress FROM stress1 TO stress5
	/INDEX month (5)
	/KEEP = ALL
	/NULL = DROP.

* Labeling all variables.
VARIABLE LABELS 	
   PersonID 	"PersonID: Unique Identifier"
			baseage  	"baseage: Age at Baseline"
			treat 	   "treat: Treatment Group (1=control, 2=treatment)"
			month  	 	"month: Month of Study"
			severity 	"severity: Time-Varying Severity Outcome"
			stress   	"stress: Time-Varying Stress Predictor"
			pmstress 	"pmstress: Person-Mean Stress Predictor".
EXECUTE.

* Center time at first occasion.
COMPUTE month1 = month - 1.
VARIABLE LABELS month1 "Month of Study (0=1)".

EXECUTE.


***********************************************************************
*****			          Multilevel Analysis using SPSS MIXED		          *****
***********************************************************************.	

* General form of MIXED:
MIXED dv BY categorical and nesting variables WITH continuous variables
	/METHOD  = REML (default) or ML
	/PRINT   = regression solution, tests of covariances, G and R matrices
	/FIXED   = model predictors and interactions
	/RANDOM  = INTERCEPT random effects | SUBJECT(idvar) COVTYPE(unstructured)
	/REPEATED = categorical time | SUBJECT(idvar) COVTYPE(whatever structure).


* Now it is your turn!.

DATASET ACTIVATE activity.

* 1: Empty Model and ICC (=.41).
TITLE "Random Intercept Only Baseline Model (equal to CS)".
MIXED severity BY PersonID month 
	/METHOD = REML
	/PRINT = SOLUTION
	/FIXED = 
	/RANDOM = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN)
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

* 2: Saturated means, unstructured R matrix model.
***  Means are declining over time, which is informative for fixed effects.
*** Variances and covariances decrease, then increase over time.
*** Informative for what kind of variance model we'll need.
TITLE "Saturdated Means, Unstructured R Baseline Model".
MIXED severity BY PersonID month
	/METHOD = REML
	/PRINT = SOLUTION TESTCOV R
	/FIXED = month
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(UN)
 /EMMEANS = TABLES(month).
TITLE.

* 3: Polynomial fixed and random effects models.

TITLE "Fixed Linear, Random Intercept Only Model".
* P-value for month1 is signif, so model fits better.
MIXED severity BY PersonID month WITH month1
	/METHOD = REML
	/PRINT = SOLUTION
	/FIXED = month1
	/RANDOM = INTERCEPT | SUBJECT(PersonID) COVTYPE(UN)
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

TITLE "Random Linear Model".
* REML deviance difference for df=2 is signif, so model fits better.
MIXED severity BY PersonID month WITH month1
	/METHOD = REML
	/PRINT = SOLUTION
	/FIXED = month1
	/RANDOM = INTERCEPT month1 | SUBJECT(PersonID) COVTYPE(UN)
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

TITLE "Fixed Quadratic, Random Linear Model".
* P-value for month1*month1 is NOT signif, so model does not fit better.
MIXED severity BY PersonID month WITH month1
	/METHOD = REML
	/PRINT = SOLUTION
	/FIXED = month1 month1*month1
	/RANDOM = INTERCEPT month1 | SUBJECT(PersonID) COVTYPE(UN)
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

TITLE "Random Quadratic Model".
* REML deviance difference for df=3 is signif, so model fits better.
MIXED severity BY PersonID month WITH month1
	/METHOD = REML
	/PRINT = SOLUTION
	/FIXED = month1 month1*month1
	/RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
	/REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.


* 4: Interpretation of final random quadratic model:

*Calculating 95% random effects confidence intervals to interpret variance components:
*CI = fixed effect  2*SQRT(variance)
*Intercept CI = 			   15.849  2*SQRT(9.433)   9.71 to 21.99
*Linear Slope CI =		   -.716  2*SQRT(2.587) 	-3.93 to 2.50
*Quadratic Slope CI =	  .052  2*SQRT(.134) 	 -0.68 to 0.78

*Summary of Final Model Parameters: 
*The average expected value of Y at the first occasion (because month is centered at 1) is 15.849, 
*and this is expected to fall between 9.71 and 21.99 for 95% of the individuals in the sample. 
*There is a significant instantaneous linear rate of decline of -.716/month as evaluated at the 
*first occasion, and this linear effect of time varies significantly over individuals. 
*Specifically, the linear slope is predicted to fall between -3.93 and 2.50 for 
*95% of the individuals in the sample. so not everyone is predicted to decline 
*(as evaluated at the first occasion). 
*Although the average deceleration in the linear rate of decline of .052/month is not significant, 
*significant individual differences were found, such that the 95% confidence interval for the 
*quadratic effect of time was -.68 to .78. Thus, individuals are predicted to demonstrate both 
*acceleration and deceleration of the initial negative trend. The interpretation of the 
*quadratic coefficient is such that for every additional month, the linear coefficient 
*of -.716 becomes .104 less negative 
*(quadratic coefficient * 2 describes how the linear trend changes per unit time) 

