* Activity 3 answers.

* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE activity /NAME = "C:\Dropbox\14_ICPSR\Download\Activities".
GET FILE = "activity/SPSS_Activity_Data.sav".
DATASET NAME activity WINDOW=FRONT.

* Getting person mean stress (for later).
COMPUTE pmstress = MEAN(stress1 TO stress5).
VARIABLE LABELS PMstress "Person Mean Stress".
EXECUTE.

* Stacking data for MIXED.
VARSTOCASES
	/MAKE severity FROM severity1 TO severity5
	/MAKE stress FROM stress1 TO stress5
	/INDEX month (5)
	/KEEP = ALL
	/NULL = DROP.

* Labeling all variables.
VARIABLE LABELS 	
   PersonID 	"PersonID: Unique Identifier"
			baseage  	"baseage: Age at Baseline"
			treat 	   "treat: Treatment Group (1=control, 2=treatment)"
			month  	 	"month: Month of Study"
			severity 	"severity: Time-Varying Severity Outcome"
			stress   	"stress: Time-Varying Stress Predictor"
			pmstress 	"pmstress: Person-Mean Stress Predictor".
EXECUTE.

* Center time at first occasion.
COMPUTE month1 = month - 1.
VARIABLE LABELS month1 "Month of Study (0=1)".

* Add the rest of your centered variables here.
COMPUTE age40 = baseage - 40.
IF (treat=1) treat0=0.
IF (treat=2) treat0=1.
VARIABLE LABELS   
	  age40  "Age at Baseline (0=40)"
			treat0 "Treatment Group (0=no, 1=yes)".
EXECUTE.


***********************************************************************
*****			          Multilevel Analysis using SPSS MIXED		          *****
***********************************************************************.	

* General form of MIXED:
MIXED dv BY categorical and nesting variables WITH continuous variables
	/METHOD  = REML (default) or ML
	/PRINT   = regression solution, tests of covariances, G and R matrices
	/FIXED   = model predictors and interactions
	/RANDOM  = INTERCEPT random effects | SUBJECT(idvar) COVTYPE(unstructured)
	/REPEATED = categorical time | SUBJECT(idvar) COVTYPE(whatever structure).

DATASET ACTIVATE activity.

* Baseline unconditional model.
TITLE "Random Quadratic Unconditional Baseline Model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

* 1: Effects of age (age 40 as reference):
	 Main effect of age --> effect on severity at month1=0
	 Age*month1 --> effect on linear slope for month
	 Age*month1*month1 --> effect on quadratic slope for month.

TITLE "Add 3 Effects of age".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV 
	/FIXED  = month1 month1*month1 
			        age40 age40*month1 age40*month1*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).\
TITLE.

TITLE "Drop age by quadratic month".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
		         age40 age40*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

TITLE "Drop age by linear month - final age model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

* 2: Effects of group using control group as a reference.

TITLE "Control vs treatment group full model".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40 
           treat0 treat0*month1 treat0*month1*month1
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID).
TITLE.

TITLE "Drop group by quadratic month".
MIXED severity BY PersonID month WITH month1 age40 treat0 
	/METHOD = ML
	/PRINT  = SOLUTION TESTCOV
	/FIXED  = month1 month1*month1 
           age40
           treat0 treat0*month1 
 /RANDOM = INTERCEPT month1 month1*month1 | SUBJECT(PersonID) COVTYPE(UN)
 /REPEATED = month | SUBJECT(PersonID) COVTYPE(ID)
	/TEST =  "a) Random assignment check (group diff at month 1)"	treat0 1 treat0*month1 0
	/TEST =  "b) Control group linear slope at month 1" 			       month1 1 month1*month1 0 treat0*month1 0
	/TEST =  "c) Control group linear slope at month 5"				       month1 1 month1*month1 8 treat0*month1 0
	/TEST =  "d) Treatment group linear slope at month 1" 			     month1 1 month1*month1 0 treat0*month1 1
	/TEST =  "e) Treatment group linear slope at month 5" 			     month1 1 month1*month1 8 treat0*month1 1
	/TEST =  "f) Treatment group diff in linear slope at month 1" treat0*month1 1
	/TEST =  "g) Treatment group diff in linear slope at month 5" treat0*month1 1
	/TEST =  "h) Group diff at month 5"								                   treat0 1 treat0*month1 4.
TITLE.



