 * Activity 2 answers

 * Open file used in example -- CHANGE THIS
use "C:\Dropbox\14_ICPSR\Download\Activities\STATA_Activity_Data.dta", clear

 * Stacking data for XTMIXED (wide to long)
 * list time-varying variables first, i(level2ID) j(newtimeID)
reshape long severity stress, i(PersonID) j(month)

 * Getting person mean stress (for use in activity 3)
egen pmstress = mean(stress), by(PersonID)

 * Labeling all variables
label variable PersonID "PersonID: Unique Identifier"
label variable baseage  "baseage: Age at Baseline"
label variable treat  	"treat: Treatment Group (1=control, 2=treatment)"
label variable month 	"month: Month of Study"
label variable severity "severity: Time-Varying Severity Outcome"
label variable stress 	"stress: Time-Varying Stress Predictor"
label variable pmstress "pmstress: Person-Mean Stress Predictor"

 * Center predictors here
gen month1 = month - 1
gen month1sq = month1 * month1
label variable month1   "Linear Month of Study (0=1)"
label variable month1sq "Quadratic Month of Study (0=1)"


///////////////////////////////////////////////////////////////////////////////////////
// mixed DV fixed effects, FE options || Level2ID: random effects, RE options ///
//	  variance reml/mle covariance(Gmatrix type) residuals(Rmatrix type), t(Level1ID),
//	  estat ic n(#persons),
//    estimates store ModelName,  
// 	  lrtest BiggerModel SmallerModel
///////////////////////////////////////////////////////////////////////////////////////

 * Now it is your turn!

 * 1: Empty Model and ICC (=.41)
 * STATA Empty Means, Random Intercept Model
mixed severity ,  || PersonID:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(month)), 
	estat ic, n(200),
	estat icc,
	estat recovariance, relevel(PersonID)
 
 * 2: Saturated means, unstructured R matrix model
 ***  Means are declining over time, which is informative for fixed effects
 *** Variances and covariances decrease, then increase over time
 *** Informative for what kind of variance model we'll need
mixed severity ib(last).month, || PersonID: , noconstant /// 
	variance reml residuals(unstructured, t(month)),
	estat ic, n(200)
	estat wcorrelation, covariance,		// R covariance matrix
	estat wcorrelation,					// R correlation matrix
	margins i.month

 * 3: Polynomial fixed and random effects models	
	
 * STATA Fixed Linear Time, Random Intercept Model
 * P-value for month1 is signif, so model fits better
mixed severity c.month1,  || PersonID:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(month)), 
	estat ic, n(200),
	estat recovariance, relevel(PersonID)
	estimates store FixLin

 * STATA Random Linear Time Model
 * REML deviance difference for df=2 is signif, so model fits better
mixed severity c.month1,  || PersonID: month1 ,  ///  
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID),
	estimates store RandLin,
	lrtest RandLin FixLin

 * STATA Fixed Quadratic, Random Linear Time Model
 * P-value for month1sq is NOT signif, so model does not fit better
mixed severity c.month1 c.month1#c.month1,  || PersonID: month1 ,  /// 
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID),
	estimates store FixQuad

 * STATA Random Quadratic Time Model
 * REML deviance difference for df=3 is signif, so model fits better
mixed severity c.month1 c.month1#c.month1,  || PersonID: month1 month1sq,  /// 
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID),
	estimates store RandQuad,
	lrtest RandQuad FixQuad
	
/* 4: Interpretation of final random quadratic model:

Calculating 95% random effects confidence intervals to interpret variance components:
CI = fixed effect  2*SQRT(variance)
Intercept CI = 			15.849  2*SQRT(9.433)   9.71 to 21.99
Linear Slope CI =		 -.716  2*SQRT(2.587) 	-3.93 to 2.50
Quadratic Slope CI =	  .052  2*SQRT(.134) 	-0.68 to 0.78

Summary of Final Model Parameters: 
The average expected value of Y at the first occasion (because month is centered at 1) is 15.849, 
and this is expected to fall between 9.71 and 21.99 for 95% of the individuals in the sample. 
There is a significant instantaneous linear rate of decline of -.716/month as evaluated at the 
first occasion, and this linear effect of time varies significantly over individuals. 
Specifically, the linear slope is predicted to fall between -3.93 and 2.50 for 
95% of the individuals in the sample. so not everyone is predicted to decline 
(as evaluated at the first occasion). 
Although the average deceleration in the linear rate of decline of .052/month is not significant, 
significant individual differences were found, such that the 95% confidence interval for the 
quadratic effect of time was -.68 to .78. Thus, individuals are predicted to demonstrate both 
acceleration and deceleration of the initial negative trend. The interpretation of the 
quadratic coefficient is such that for every additional month, the linear coefficient 
of -.716 becomes .104 less negative 
(quadratic coefficient * 2 describes how the linear trend changes per unit time).
*/
