 * Activity 3 answers

 * Open file used in example -- CHANGE THIS
use "C:\Dropbox\14_ICPSR\Download\Activities\STATA_Activity_Data.dta", clear

 * Stacking data for XTMIXED (wide to long)
 * list time-varying variables first, i(level2ID) j(newtimeID)
reshape long severity stress, i(PersonID) j(month)

 * Getting person mean stress (for use in activity 3)
egen pmstress = mean(stress), by(PersonID)

 * Labeling all variables
label variable PersonID "PersonID: Unique Identifier"
label variable baseage  "baseage: Age at Baseline"
label variable treat  	"treat: Treatment Group (1=control, 2=treatment)"
label variable month 	"month: Month of Study"
label variable severity "severity: Time-Varying Severity Outcome"
label variable stress 	"stress: Time-Varying Stress Predictor"
label variable pmstress "pmstress: Person-Mean Stress Predictor"

 * Center predictors here
gen month1 = month - 1
gen month1sq = month1 * month1
label variable month1   "Linear Month of Study (0=1)"
label variable month1sq "Quadratic Month of Study (0=1)"

 * Center age at 40
gen age40 = baseage - 40
label variable age40 "Baseline Age (0=40)" 

 * Recode treatment group 
gen treat0 = treat
recode treat0 (1=0) (2=1)
label variable treat0 "Treatment Group (0=C, 1=T)"


///////////////////////////////////////////////////////////////////////////////////////
// mixed DV fixed effects, FE options || Level2ID: random effects, RE options ///
//	  variance reml/mle covariance(Gmatrix type) residuals(Rmatrix type), t(Level1ID),
//	  estat ic n(#persons),
//    estimates store ModelName,  
// 	  lrtest BiggerModel SmallerModel
///////////////////////////////////////////////////////////////////////////////////////

 * Now it is your turn!

 * STATA Random Quadratic Time Baseline Model
mixed severity c.month1 c.month1sq,  || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)

 * 1: Effects of age (age 40 as reference):
 *	 Main effect of age --> effect on severity at month1=0
 *	 Age*month1 --> effect on linear slope for month
 *	 Age*month1*month1 --> effect on quadratic slope for month 
	
 * STATA Add 3 effects of age
mixed severity c.month1 c.month1#c.month1 c.age40 c.age40#c.month1 c.age40#c.month1#c.month1 ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)
	 
 * STATA Drop age by quadratic month
mixed severity c.month1 c.month1#c.month1 c.age40 c.age40#c.month1 ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)
	
 * STATA Drop age by linear month - final age model
mixed severity c.month1 c.month1#c.month1 c.age40 ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)
	

 * 2: Effects of group using control group as a reference

 * STATA Control vs. treatment group full model
mixed severity c.month1 c.month1#c.month1 c.age40 ///
	c.treat0 c.treat0#c.month1 c.treat0#c.month1#c.month1  ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)

 * STATA Drop group by quadratic month
mixed severity c.month1 c.month1#c.month1 c.age40 ///
	c.treat0 c.treat0#c.month1   ///
    || PersonID: month1 month1sq,  /// 
	variance mle covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, relevel(PersonID)
lincom 1*c.treat0 + 0*c.treat0#c.month1  						// a) Random assignment check (group diff at month 1)
lincom 1*c.month1 + 0*c.month1#c.month1 + 0*c.treat0#c.month1 	// b) Control group linear slope at month 1
lincom 1*c.month1 + 8*c.month1#c.month1 + 0*c.treat0#c.month1   // c) Control group linear slope at month 5
lincom 1*c.month1 + 0*c.month1#c.month1 + 1*c.treat0#c.month1 	// d) Treatment group linear slope at month 1
lincom 1*c.month1 + 8*c.month1#c.month1 + 1*c.treat0#c.month1 	// e) Treatment group linear slope at month 5
lincom 1*c.treat0#c.month1 										// f) Control group linear slope at month 1
lincom 1*c.treat0#c.month1 										// g) Control group linear slope at month 5
lincom 1*c.treat0 + 4*c.treat0#c.month1							// h) Group diff at month 5
	
