* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=100 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for original SAS files for these models;
%LET example = C:\Dropbox\14_ICPSR\Download\SAS;
LIBNAME example "&example.";
	
* Bring in SAS file with macro programs;
%INCLUDE "&example.\MLM_Macros.sas";

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example6_SAS_Output.txt" 
			 LOG=  "&example.\Example6_SAS_Output.txt"; RUN;

* SAS code to read data into work library and center predictors;
DATA work.Example6; SET example.Example6;
* Level-2 effect of Negative Mood (mean=0, SD=1);
  PMnm0 = PMnegmood - 0;  LABEL PMnm0 = "PMnm0: Person Mean Negative Mood (0=0)";
* Level-1 effect to use with PERSON-MEAN-CENTERING;
  WPnm  = negmood  - PMnegmood; LABEL wpnm  = "WPnm: Within-Person Negative Mood (0=PM)";
* Level-1 effect to use with GRAND-MEAN-CENTERING;
  TVnm0 = negmood - 0; LABEL TVnm0  = "TVnm0: Time-Varying Negative Mood (0=0)";
* Gender already exists; 
  LABEL sexMW = "Participant Sex (0=M, 1=W)"; 
RUN;


******************************************************************************
****** 						EXAMPLE 6 MODELS							******
******************************************************************************;

*** PART 1: VARIANCE DECOMPOSITION;

TITLE1 "SAS Model 1a: Empty Model for Daily Glucose Outcome";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / VCORR SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovEmpty InfoCrit=FitEmpty; * Save covparms, fit;
RUN; TITLE1;

TITLE1 "SAS Model 1b: Empty Model for Daily Negative Mood Predictor";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL negmood = / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / VCORR SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
RUN; TITLE1;

*** PART 2: PERSON-MEAN-CENTERING OF NEGATIVE MOOD TO PREDICT GLUCOSE;

TITLE1 "SAS Model 2a: Fixed Effects of Negative Mood using PMC";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = WPnm PMnm0 / SOLUTION DDFM=Satterthwaite OUTPM=PredMood; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovMood InfoCrit=FitMood; * Save covparms, fit;
	ESTIMATE "Within-Person Mood Effect" 	WPnm  1;
	ESTIMATE "Between-Person Mood Effect" 	PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1 WPnm -1;
RUN; TITLE1;
* Calculate PseudoR2 relative to empty model;
%PseudoR2(NCov=2, CovFewer=CovEmpty, CovMore=CovMood);
* Calculate Total R2 (nothing to compare it to yet);
PROC CORR DATA=PredMood; VAR lGlucAM pred; RUN;
* Calculate difference in model fit relative to empty model;
%FitTest(FitFewer=FitEmpty, FitMore=FitMood);

TITLE1 "SAS Model 2b: Random Effect of WP Negative Mood using PMC";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = WPnm PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT WPnm / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT InfoCrit=FitRandMood; * Save fit;
	ESTIMATE "Within-Person Mood Effect" 	WPnm  1;
	ESTIMATE "Between-Person Mood Effect" 	PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 	PMnm0 1 WPnm -1;  
RUN; TITLE1;
* Calculate difference in model fit relative to fixed WPnm model;
%FitTest(FitFewer=FitMood, FitMore=FitRandMood);

TITLE1 "SAS Model 2c: Fixed Effects of Sex (0=M, 1=F) by PMC Negative Mood";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lGlucAM = WPnm PMnm0 sexMW WPnm*sexMW PMnm0*sexMW 
						/ SOLUTION DDFM=Satterthwaite OUTPM=PredSex; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovSex InfoCrit=FitSex; * Save covparms, fit;
	ESTIMATE "Intercept: Men (Mood=0)"			 intercept 1 sexMW 0;
	ESTIMATE "Intercept: Women (Mood=0)"		 intercept 1 sexMW 1;
	ESTIMATE "Intercept: Women Diff (Mood=0)" 	 sexMW 1;
	ESTIMATE "Within-Person Effect: Men" 		 WPnm 1 WPnm*sexMW 0;
	ESTIMATE "Within-Person Effect: Women" 		 WPnm 1 WPnm*sexMW 1;
	ESTIMATE "Within-Person Effect: Women Diff"  WPnm*sexMW 1;
	ESTIMATE "Between-Person Effect: Men" 		 PMnm0 1 PMnm0*sexMW 0;
	ESTIMATE "Between-Person Effect: Women" 	 PMnm0 1 PMnm0*sexMW 1;
	ESTIMATE "Between-Person Effect: Women Diff" PMnm0*sexMW 1;
	ESTIMATE "Contextual Effect: Men" 			 WPnm -1 WPnm*sexMW  0 PMnm0 1 PMnm0*sexMW 0;
	ESTIMATE "Contextual Effect: Women" 		 WPnm -1 WPnm*sexMW -1 PMnm0 1 PMnm0*sexMW 1;
	ESTIMATE "Contextual Effect: Women Diff"     WPnm*sexMW -1 PMnm0*sexMW 1;
RUN; TITLE1;
* Calculate PseudoR2 relative to fixed-mood-only model;
%PseudoR2(NCov=2, CovFewer=CovMood, CovMore=CovSex);
* Calculate Total R2 change relative to fixed-mood-only model;
%TotalR2(DV=lGlucAM, PredFewer=PredMood, PredMore=PredSex);
* Calculate difference in model fit relative to fixed-mood-only model;
%FitTest(FitFewer=FitMood, FitMore=FitSex);

TITLE1 "SAS Model 2c: Fixed Effects of Sex (0=M, 1=W) by PMC Negative Mood";
TITLE2 "USING CLASS STATEMENT FOR GENDER";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day sexMW;
	MODEL lGlucAM = WPnm PMnm0 sexMW WPnm*sexMW PMnm0*sexMW 
		/ SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovSex InfoCrit=FitSex; * Save covparms, fit;
	ESTIMATE "Intercept: Men"						intercept 1 sexMW 1 0;
	ESTIMATE "Intercept: Women"						intercept 1 sexMW 0 1;
	ESTIMATE "Intercept: Women Diff" 				sexMW -1 1;
	ESTIMATE "Within-Person Effect: Men" 			WPnm 1 WPnm*sexMW 1 0;
	ESTIMATE "Within-Person Effect: Women" 			WPnm 1 WPnm*sexMW 0 1;
	ESTIMATE "Within-Person Effect: Women Diff"		WPnm*sexMW -1 1;
	ESTIMATE "Between-Person Effect: Men" 	   		PMnm0 1 PMnm0*sexMW 1 0;
	ESTIMATE "Between-Person Effect: Women" 		PMnm0 1 PMnm0*sexMW 0 1;
	ESTIMATE "Between-Person Effect: Women Diff" 	PMnm0*sexMW -1 1; 
	ESTIMATE "Context Effect: Men"   			WPnm -1 WPnm*sexMW -1 0 PMnm0 1 PMnm0*sexMW 1 0;
	ESTIMATE "Context Effect: Women" 			WPnm -1 WPnm*sexMW 0 -1 PMnm0 1 PMnm0*sexMW 0 1;
	ESTIMATE "Context Effect: Women Diff" 		WPnm*sexMW 1 -1 PMnm0*sexMW -1 1;
RUN; TITLE1; TITLE2;


*** PART 3: GRAND-MEAN-CENTERING OF NEGATIVE MOOD TO PREDICT GLUCOSE;

TITLE1 "SAS Model 3: Fixed Effect of TV Negative Mood only using GMC";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovSmush; * Save covparms;
RUN; TITLE1;
* Calculate PseudoR2 relative to empty model;
%PseudoR2(NCov=2, CovFewer=CovEmpty, CovMore=CovSmush);

TITLE1 "SAS Model 3a: Fixed Effects of Negative Mood using GMC";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovMood InfoCrit=FitMood; * Save covparms, fit;
	ESTIMATE "Within-Person Mood Effect" 	TVnm0 1;
	ESTIMATE "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1;  
RUN; TITLE1;
* Calculate PseudoR2 relative to smushed model;
%PseudoR2(NCov=2, CovFewer=CovSmush, CovMore=CovMood);

TITLE1 "SAS Model 3b: Random Effect of TV Negative Mood using GMC";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lglucAM = TVnm0 PMnm0 / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT TVnm0 / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT InfoCrit=FitTVRandMood; * Save fit;
	ESTIMATE "Within-Person Mood Effect" 	TVnm0 1;
	ESTIMATE "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1;
	ESTIMATE "Contextual Mood Effect" 		PMnm0 1;  
RUN; TITLE1; 
* Calculate difference in model fit relative to fixed-mood-only model;
%FitTest(FitFewer=FitMood, FitMore=FitTVRandMood);

TITLE1 "SAS Model 3c: Fixed Effects of Sex (0=M, 1=W) by GMC Negative Mood";
PROC MIXED DATA=work.Example6 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=ML;
	CLASS ID day;
	MODEL lGlucAM = TVnm0 PMnm0 sexMW TVnm0*sexMW PMnm0*sexMW 
						/ SOLUTION DDFM=Satterthwaite OUTPM=PredSex; 
	RANDOM INTERCEPT  / SUBJECT=ID TYPE=UN; 
	REPEATED day / SUBJECT=ID TYPE=VC; 
	ODS OUTPUT CovParms=CovSex InfoCrit=FitSex; * Save covparms, fit;
	ESTIMATE "Intercept: Men"					 intercept 1 sexMW 0;
	ESTIMATE "Intercept: Women"					 intercept 1 sexMW 1;
	ESTIMATE "Intercept: Women Diff" 			 sexMW 1;
	ESTIMATE "Within-Person Effect: Men" 		 TVnm0 1 TVnm0*sexMW 0;
	ESTIMATE "Within-Person Effect: Women" 		 TVnm0 1 TVnm0*sexMW 1;
	ESTIMATE "Within-Person Effect: Women Diff"  TVnm0*sexMW 1;
	ESTIMATE "Between-Person Effect: Men" 		 TVnm0 1 TVnm0*sexMW 0 PMnm0 1 PMnm0*sexMW 0;
	ESTIMATE "Between-Person Effect: Women" 	 TVnm0 1 TVnm0*sexMW 1 PMnm0 1 PMnm0*sexMW 1;
	ESTIMATE "Between-Person Effect: Women Diff" TVnm0*sexMW 1 PMnm0*sexMW 1;
	ESTIMATE "Contextual Effect: Men" 		 	 PMnm0 1 PMnm0*sexMW 0;
	ESTIMATE "Contextual Effect: Women" 	 	 PMnm0 1 PMnm0*sexMW 1;
	ESTIMATE "Contextual Effect: Women Diff" 	 PMnm0*sexMW 1;
RUN; TITLE1;
* Calculate PseudoR2 relative to fixed-mood-only model;
%PseudoR2(NCov=2, CovFewer=CovMood, CovMore=CovSex);
* Calculate Total R2 change relative to fixed-mood-only model;
%TotalR2(DV=lGlucAM, PredFewer=PredMood, PredMore=PredSex);
* Calculate difference in model fit relative to fixed-mood-only model;
%FitTest(FitFewer=FitMood, FitMore=FitSex);

* Close output;
PROC PRINTTO; RUN;
